# AmbTu

[![License AGPL-3.0](https://img.shields.io/badge/license-AGPL--3.0-blue.svg)](http://www.gnu.org/licenses/agpl-3.0)

## Description

The **AmbTu** module is a customization of Odoo developed to meet the specific needs of
AmbTu.

## Features

- **Invoice Customizations**:
  - Modifications to the invoice print format.

## Usage

Once installed, the customizations will be available in the Odoo invoicing module. You
can navigate to the invoicing section to see the print formats added by the AmbTu
module.

## Contributing

Contributions are welcome! Please follow these steps:

1. Fork the repository.
2. Create a new branch (`git checkout -b feature-branch`).
3. Commit your changes (`git commit -am 'Add new feature'`).
4. Push to the branch (`git push origin feature-branch`).
5. Create a new Pull Request.

## License

This project is licensed under the AGPL-3.0 License - see the [LICENSE](LICENSE) file
for details.
